﻿# Скрипт собирает инфо о модели ПК, дисках и разделах
# Автор: Вадим Стеркин (при участии Вадимса Поданса)
# Подробности http://www.outsidethebox.ms/15841/
Add-Type -AssemblyName Microsoft.VisualBasic
# Определяем изготовителя и модель ПК
$PC = Get-WmiObject Win32_ComputerSystem
if ($PC.Manufacturer.Contains("filled") -or $PC.Manufacturer.Contains("manufacturer")) {
	$PCInfo = "Модель ПК не определена"
} else {
	$PCInfo = $PC.manufacturer,$PC.model
}
# Определяем версию ОС
$OSVersion = [double][environment]::osversion.Version.tostring(2)

# Выбираем метод сбора инфо в зависимости от версии ОС
# http://msdn.microsoft.com/library/windows/desktop/ms724832(v=vs.85).aspx
# И получаем инфо о дисках и разделах
if ($OSVersion -gt "6.1") {
	# Windows 8 и новее
	# Инфо о физических дисках
	$PhysicalDiskInfo = Get-PhysicalDisk | Sort-Object DeviceID | Format-Table -AutoSize `
		@{Expression = {$_.DeviceId}; Label="Диск"},
		@{Expression = {$_.Model}; Label="Название"},
		@{Expression = {$_.MediaType}; Label="Тип"},
		@{Expression = {$_.BusType}; Label="Шина"},
		@{Expression = {[int]($_.Size/1GB)}; Label="Размер (GB)"}
	# Расклад по разделам дисков
	$DiskInfo = Get-Disk | Sort-Object Number | ForEach-Object {
		# Инфо о диске
		$_ | Format-Table -AutoSize `
			@{Expression = {$_.Number}; Label = "Диск"},
			@{Expression = {$_.FriendlyName}; Label = "Название"},
			@{Expression = {[int]($_.Size/1GB)}; Label = "Размер (GB)"},
			@{Expression = {$_.PartitionStyle}; Label = "Разметка"}
		# Инфо о разделах диска
		Get-Partition -DiskNumber $_.Number | Format-Table -AutoSize `
			@{Expression = {$_.PartitionNumber}; Label = "Раздел"},
			@{Expression = {$_.DriveLetter}; Label = "Буква"},
			@{Expression = {[int]($_.Size/1mb)}; Label = "Размер (MB)"},
			@{Expression = {[int]($_.Offset/1kb)}; Label = "Смещение (KB)"},
			# в diskmgmt.msc - "Система"
			@{Expression = {$_.IsBoot}; Label = "Установлена ОС"},
			# в diskmgmt.msc - "Загрузка"
			@{Expression = {$_.IsSystem}; Label = "Файлы загрузки"},
			@{Expression = {$_.Type}; Label = "Тип"}
	}
} else {
	# Windows 7
    # Расположение скрипта
    $PSScriptRoot = Split-Path -Parent -Path $MyInvocation.MyCommand.Definition
	# Инфо о дисках и разделах
	$DiskDrive = @(Get-WmiObject Win32_DiskDrive)
	$Partitions = Get-WmiObject Win32_DiskPartition
	$DiskInfo = for ($index = 0; $index -lt $DiskDrive.Count; $index++) {
		$DiskDrive | Where-Object {$_.index -eq $index} | Format-Table -AutoSize `
			@{Expression={$_.Index};Label="Диск"},
			@{Expression={$_.Caption};Label="Модель"},
			@{Expression={[int]($_.Size/1gb)};Label="Размер (GB)"}
		$Partitions | Where-Object {$_.diskindex -eq $index} | Format-Table -AutoSize `
			@{Expression={$_.Index+1};Label="Раздел"},
			@{Expression={[int]($_.Size/1mb)};Label="Размер (MB)"},
			@{Expression={[int]($_.StartingOffset/1kb)};Label="Смещение (KB)"},
			# в diskmgmt.msc - "Система"
			@{Expression={$_.BootPartition};Label="Файлы загрузки"},
			@{Expression={$_.Type};Label="Тип"}
	}

	# Инфо о томах (нужны буквы дисков)
	$VolumeInfo = Get-WmiObject Win32_Volume | Format-Table -AutoSize `
		@{Expression = {$_.DriveLetter}; Label = "Буква диска"},
		@{Expression = {[int]($_.Capacity/1mb)}; Label = "Размер (MB)"}
}

#Записываем отчет в файл
$Report = "$PSScriptRoot\disk-info.txt"
$PCInfo | Out-File $Report
(New-Object Microsoft.VisualBasic.Devices.ComputerInfo).OSFullName | Out-File $Report -append
# Код для блога (складывает отчет)
'[code collapse="true" title="Сведения о дисках и разделах"]' | Out-File $Report -append
# Только в Windows 8 и новее
if ($OSVersion -gt "6.1") {
	'Физические диски' | Out-File $Report -append
	$PhysicalDiskInfo | Out-File $Report -append
}
'Расклад по дискам и разделам' | Out-File $Report -append
$DiskInfo | Out-File $Report -append
# В Windows 7 и новее
if ($OSVersion -le "6.1") {
	'Расклад по томам' | Out-File $Report -append
	$VolumeInfo | Out-File $Report -append
}
'[/code]' | Out-File $Report -append
Start-Sleep 1
notepad $Report
# SIG # Begin signature block
# MIIfRQYJKoZIhvcNAQcCoIIfNjCCHzICAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUd5fn69XuSOmUp10D3aSVWd+l
# In2gghp/MIIGajCCBVKgAwIBAgIQA5/t7ct5W43tMgyJGfA2iTANBgkqhkiG9w0B
# AQUFADBiMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYD
# VQQLExB3d3cuZGlnaWNlcnQuY29tMSEwHwYDVQQDExhEaWdpQ2VydCBBc3N1cmVk
# IElEIENBLTEwHhcNMTMwNTIxMDAwMDAwWhcNMTQwNjA0MDAwMDAwWjBHMQswCQYD
# VQQGEwJVUzERMA8GA1UEChMIRGlnaUNlcnQxJTAjBgNVBAMTHERpZ2lDZXJ0IFRp
# bWVzdGFtcCBSZXNwb25kZXIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQC6aUqBTW+lFBaqis1nvku/xmmPWBzgeegenVgmmNpc1Hyj+dsrjBI2w/z5ZAax
# u8KomAoXDeGV60C065ZtmL+mj3nPvIqSe22cGAZR2KUYUzIBJxlh6IRB38bw6Mr+
# d61f2J57jGBvhVxGvWvnD4DO5wPDfDHPt2VVxvvgmQjkc1r7l9rQTL60tsYPfyaS
# qbj8OO605DqkSNBM6qlGJ1vPkhGTnBan/tKtHyLFHqzBce+8StsBCUTfmBwtZ7qo
# igMzyVG19wJNCaRN/oBexddFw30IqgEzzDPYTzAW5P8iMi7rfjvw+R4y65Ul0vL+
# bVSEutXl1NHdG6+9WXuUhTABAgMBAAGjggM1MIIDMTAOBgNVHQ8BAf8EBAMCB4Aw
# DAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDCCAb8GA1UdIASC
# AbYwggGyMIIBoQYJYIZIAYb9bAcBMIIBkjAoBggrBgEFBQcCARYcaHR0cHM6Ly93
# d3cuZGlnaWNlcnQuY29tL0NQUzCCAWQGCCsGAQUFBwICMIIBVh6CAVIAQQBuAHkA
# IAB1AHMAZQAgAG8AZgAgAHQAaABpAHMAIABDAGUAcgB0AGkAZgBpAGMAYQB0AGUA
# IABjAG8AbgBzAHQAaQB0AHUAdABlAHMAIABhAGMAYwBlAHAAdABhAG4AYwBlACAA
# bwBmACAAdABoAGUAIABEAGkAZwBpAEMAZQByAHQAIABDAFAALwBDAFAAUwAgAGEA
# bgBkACAAdABoAGUAIABSAGUAbAB5AGkAbgBnACAAUABhAHIAdAB5ACAAQQBnAHIA
# ZQBlAG0AZQBuAHQAIAB3AGgAaQBjAGgAIABsAGkAbQBpAHQAIABsAGkAYQBiAGkA
# bABpAHQAeQAgAGEAbgBkACAAYQByAGUAIABpAG4AYwBvAHIAcABvAHIAYQB0AGUA
# ZAAgAGgAZQByAGUAaQBuACAAYgB5ACAAcgBlAGYAZQByAGUAbgBjAGUALjALBglg
# hkgBhv1sAxUwHwYDVR0jBBgwFoAUFQASKxOYspkH7R7for5XDStnAs0wHQYDVR0O
# BBYEFGMvyd95knu1I8q74aTuM37j4p36MH0GA1UdHwR2MHQwOKA2oDSGMmh0dHA6
# Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3VyZWRJRENBLTEuY3JsMDig
# NqA0hjJodHRwOi8vY3JsNC5kaWdpY2VydC5jb20vRGlnaUNlcnRBc3N1cmVkSURD
# QS0xLmNybDB3BggrBgEFBQcBAQRrMGkwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3Nw
# LmRpZ2ljZXJ0LmNvbTBBBggrBgEFBQcwAoY1aHR0cDovL2NhY2VydHMuZGlnaWNl
# cnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEQ0EtMS5jcnQwDQYJKoZIhvcNAQEFBQAD
# ggEBAKt0vUAATHYVJVc90xwD/31FyEUSZucoZWDY3zuz+g3BrDOP9IG5YfGd+5hV
# 195HQ7qAPfFIzD9nMFYfzvTQTIS9h6SexeEPqAZd0C9uXtwZ6PCH6uBOrz1sII5z
# b37WhxjghtOa/J7qjHLpQQ+4cbU4LPgpstUcop0b7F8quNw3IOHLu/DQbGyls8uf
# SvZU4yY0PS64wSsct/bDPf7RLR5Q9JTI+P3uc9tJtRv09f+lkME5FBvY7XEbapj7
# +kCaRKkpDlVeeLi3pIPDcAHwZkDlrnk04StNA6Et5ttUYhjt1QmLoqrWDMhPGr6Z
# JXhpmYnUWYne34jw02dedKWdpkQwggaVMIIFfaADAgECAhAHypOqbSew/S4zk418
# 7s9gMA0GCSqGSIb3DQEBBQUAMG8xCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdp
# Q2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xLjAsBgNVBAMTJURp
# Z2lDZXJ0IEFzc3VyZWQgSUQgQ29kZSBTaWduaW5nIENBLTEwHhcNMTMwMjI2MDAw
# MDAwWhcNMTQwMzAzMTIwMDAwWjBhMQswCQYDVQQGEwJVUzELMAkGA1UECBMCSU4x
# FTATBgNVBAcTDEluZGlhbmFwb2xpczEWMBQGA1UEChMNVmFkaW0gU3RlcmtpbjEW
# MBQGA1UEAxMNVmFkaW0gU3RlcmtpbjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC
# AQoCggEBAKybgT7r6mWg94iy3omrQCAWSEUucJ8138V5XW28zReSKBVfFRdbZITY
# gD7Z1kSLtACN3/ztNhA6xaXfVMzE644oq7R0wnGWlTseW4wB6tVJZAXtdEdlic5K
# vv/7jY5UHm90rRtzcRGtiwZAkjIdzMCtAg8XMvIUzMFucoVEoSfzhZsTgRxheFqv
# cuJCpHr4fW2vyquSFVzAtLMVRSovsEp9UKdwvjAO3yZPlVnxa9x6/75dLQbDEaLB
# Y+z++KODXbAvjF6jNGw85yDsfxVOC7xvHH32ROOi3ugUfGXRWmzhotrkW9gnJb/z
# seFpTTeCJUdgwJRAicD2iAxzReLMqNcCAwEAAaOCAzkwggM1MB8GA1UdIwQYMBaA
# FHtozimqwBe+SXrh5T/Wp/dFjzUyMB0GA1UdDgQWBBRm/19cNnbnke4bvuPIMgV7
# X3I4BTAOBgNVHQ8BAf8EBAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwMwcwYDVR0f
# BGwwajAzoDGgL4YtaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL2Fzc3VyZWQtY3Mt
# MjAxMWEuY3JsMDOgMaAvhi1odHRwOi8vY3JsNC5kaWdpY2VydC5jb20vYXNzdXJl
# ZC1jcy0yMDExYS5jcmwwggHEBgNVHSAEggG7MIIBtzCCAbMGCWCGSAGG/WwDATCC
# AaQwOgYIKwYBBQUHAgEWLmh0dHA6Ly93d3cuZGlnaWNlcnQuY29tL3NzbC1jcHMt
# cmVwb3NpdG9yeS5odG0wggFkBggrBgEFBQcCAjCCAVYeggFSAEEAbgB5ACAAdQBz
# AGUAIABvAGYAIAB0AGgAaQBzACAAQwBlAHIAdABpAGYAaQBjAGEAdABlACAAYwBv
# AG4AcwB0AGkAdAB1AHQAZQBzACAAYQBjAGMAZQBwAHQAYQBuAGMAZQAgAG8AZgAg
# AHQAaABlACAARABpAGcAaQBDAGUAcgB0ACAAQwBQAC8AQwBQAFMAIABhAG4AZAAg
# AHQAaABlACAAUgBlAGwAeQBpAG4AZwAgAFAAYQByAHQAeQAgAEEAZwByAGUAZQBt
# AGUAbgB0ACAAdwBoAGkAYwBoACAAbABpAG0AaQB0ACAAbABpAGEAYgBpAGwAaQB0
# AHkAIABhAG4AZAAgAGEAcgBlACAAaQBuAGMAbwByAHAAbwByAGEAdABlAGQAIABo
# AGUAcgBlAGkAbgAgAGIAeQAgAHIAZQBmAGUAcgBlAG4AYwBlAC4wgYIGCCsGAQUF
# BwEBBHYwdDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEwG
# CCsGAQUFBzAChkBodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRB
# c3N1cmVkSURDb2RlU2lnbmluZ0NBLTEuY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZI
# hvcNAQEFBQADggEBAI+dvK1turqEJr/3+TlFTgFtJOZ4Qc6mUGOW/8+dZ86L2SBx
# YrWdPMapvaJXIiCtaWgcb7O9BXoOHHqks2cFt5FP7Q9Xxr/81VmAMQefYhxo4VST
# neYeYfMsxoqSBLMebrap9MHK5iYk3pVk/8AnJiXmI4nf29CScU4oHt6fhcQIekIk
# q+H8O8OS2v+Dq2cjxKL/uC9LB/770OG0Curx6SWj0aYh5/8pWYp8V2b27XvSlkNN
# RK+Po5HfpLVBMcxLnlv6sNw7pzD1JJGjtphgrnqOi5TLH64jBNdQ1bnMh9ZRDRQg
# iQGYpX9kvz18cAYAnPgZ0B478CcRPhVzAJQO5VAwggajMIIFi6ADAgECAhAPqEkG
# FdcAoL4hdv3F7G29MA0GCSqGSIb3DQEBBQUAMGUxCzAJBgNVBAYTAlVTMRUwEwYD
# VQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xJDAi
# BgNVBAMTG0RpZ2lDZXJ0IEFzc3VyZWQgSUQgUm9vdCBDQTAeFw0xMTAyMTExMjAw
# MDBaFw0yNjAyMTAxMjAwMDBaMG8xCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdp
# Q2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xLjAsBgNVBAMTJURp
# Z2lDZXJ0IEFzc3VyZWQgSUQgQ29kZSBTaWduaW5nIENBLTEwggEiMA0GCSqGSIb3
# DQEBAQUAA4IBDwAwggEKAoIBAQCcfPmgjwrKiUtTmjzsGSJ/DMv3SETQPyJumk/6
# zt/G0ySR/6hSk+dy+PFGhpTFqxf0eH/Ler6QJhx8Uy/lg+e7agUozKAXEUsYIPO3
# vfLcy7iGQEUfT/k5mNM7629ppFwBLrFm6aa43Abero1i/kQngqkDw/7mJguTSXHl
# OG1O/oBcZ3e11W9mZJRru4hJaNjR9H4hwebFHsnglrgJlflLnq7MMb1qWkKnxAVH
# fWAr2aFdvftWk+8b/HL53z4y/d0qLDJG2l5jvNC4y0wQNfxQX6xDRHz+hERQtIwq
# PXQM9HqLckvgVrUTtmPpP05JI+cGFvAlqwH4KEHmx9RkO12rAgMBAAGjggNDMIID
# PzAOBgNVHQ8BAf8EBAMCAYYwEwYDVR0lBAwwCgYIKwYBBQUHAwMwggHDBgNVHSAE
# ggG6MIIBtjCCAbIGCGCGSAGG/WwDMIIBpDA6BggrBgEFBQcCARYuaHR0cDovL3d3
# dy5kaWdpY2VydC5jb20vc3NsLWNwcy1yZXBvc2l0b3J5Lmh0bTCCAWQGCCsGAQUF
# BwICMIIBVh6CAVIAQQBuAHkAIAB1AHMAZQAgAG8AZgAgAHQAaABpAHMAIABDAGUA
# cgB0AGkAZgBpAGMAYQB0AGUAIABjAG8AbgBzAHQAaQB0AHUAdABlAHMAIABhAGMA
# YwBlAHAAdABhAG4AYwBlACAAbwBmACAAdABoAGUAIABEAGkAZwBpAEMAZQByAHQA
# IABDAFAALwBDAFAAUwAgAGEAbgBkACAAdABoAGUAIABSAGUAbAB5AGkAbgBnACAA
# UABhAHIAdAB5ACAAQQBnAHIAZQBlAG0AZQBuAHQAIAB3AGgAaQBjAGgAIABsAGkA
# bQBpAHQAIABsAGkAYQBiAGkAbABpAHQAeQAgAGEAbgBkACAAYQByAGUAIABpAG4A
# YwBvAHIAcABvAHIAYQB0AGUAZAAgAGgAZQByAGUAaQBuACAAYgB5ACAAcgBlAGYA
# ZQByAGUAbgBjAGUALjASBgNVHRMBAf8ECDAGAQH/AgEAMHkGCCsGAQUFBwEBBG0w
# azAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEMGCCsGAQUF
# BzAChjdodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRBc3N1cmVk
# SURSb290Q0EuY3J0MIGBBgNVHR8EejB4MDqgOKA2hjRodHRwOi8vY3JsMy5kaWdp
# Y2VydC5jb20vRGlnaUNlcnRBc3N1cmVkSURSb290Q0EuY3JsMDqgOKA2hjRodHRw
# Oi8vY3JsNC5kaWdpY2VydC5jb20vRGlnaUNlcnRBc3N1cmVkSURSb290Q0EuY3Js
# MB0GA1UdDgQWBBR7aM4pqsAXvkl64eU/1qf3RY81MjAfBgNVHSMEGDAWgBRF66Kv
# 9JLLgjEtUYunpyGd823IDzANBgkqhkiG9w0BAQUFAAOCAQEAe3IdZP+IyDrBt+nn
# qcSHu9uUkteQWTP6K4feqFuAJT8Tj5uDG3xDxOaM3zk+wxXssNo7ISV7JMFyXbhH
# kYETRvqcP2pRON60Jcvwq9/FKAFUeRBGJNE4DyahYZBNur0o5j/xxKqb9to1U0/J
# 8j3TbNwj7aqgTWcJ8zqAPTz7NkyQ53ak3fI6v1Y1L6JMZejg1NrRx8iRai0jTzc7
# GZQY1NWcEDzVsRwZ/4/Ia5ue+K6cmZZ40c2cURVbQiZyWo0KSiOSQOiG3iLCkzrU
# m2im3yl/Brk8Dr2fxIacgkdCcTKGCZlyCXlLnXFp9UH/fzl3ZPGEjb6LHrJ9aKOl
# kLEM/zCCBs0wggW1oAMCAQICEAb9+QOWA63qAArrPye7uhswDQYJKoZIhvcNAQEF
# BQAwZTELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UE
# CxMQd3d3LmRpZ2ljZXJ0LmNvbTEkMCIGA1UEAxMbRGlnaUNlcnQgQXNzdXJlZCBJ
# RCBSb290IENBMB4XDTA2MTExMDAwMDAwMFoXDTIxMTExMDAwMDAwMFowYjELMAkG
# A1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRp
# Z2ljZXJ0LmNvbTEhMB8GA1UEAxMYRGlnaUNlcnQgQXNzdXJlZCBJRCBDQS0xMIIB
# IjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6IItmfnKwkKVpYBzQHDSnlZU
# XKnE0kEGj8kz/E1FkVyBn+0snPgWWd+etSQVwpi5tHdJ3InECtqvy15r7a2wcTHr
# zzpADEZNk+yLejYIA6sMNP4YSYL+x8cxSIB8HqIPkg5QycaH6zY/2DDD/6b3+6LN
# b3Mj/qxWBZDwMiEWicZwiPkFl32jx0PdAug7Pe2xQaPtP77blUjE7h6z8rwMK5nQ
# xl0SQoHhg26Ccz8mSxSQrllmCsSNvtLOBq6thG9IhJtPQLnxTPKvmPv2zkBdXPao
# 8S+v7Iki8msYZbHBc63X8djPHgp0XEK4aH631XcKJ1Z8D2KkPzIUYJX9BwSiCQID
# AQABo4IDejCCA3YwDgYDVR0PAQH/BAQDAgGGMDsGA1UdJQQ0MDIGCCsGAQUFBwMB
# BggrBgEFBQcDAgYIKwYBBQUHAwMGCCsGAQUFBwMEBggrBgEFBQcDCDCCAdIGA1Ud
# IASCAckwggHFMIIBtAYKYIZIAYb9bAABBDCCAaQwOgYIKwYBBQUHAgEWLmh0dHA6
# Ly93d3cuZGlnaWNlcnQuY29tL3NzbC1jcHMtcmVwb3NpdG9yeS5odG0wggFkBggr
# BgEFBQcCAjCCAVYeggFSAEEAbgB5ACAAdQBzAGUAIABvAGYAIAB0AGgAaQBzACAA
# QwBlAHIAdABpAGYAaQBjAGEAdABlACAAYwBvAG4AcwB0AGkAdAB1AHQAZQBzACAA
# YQBjAGMAZQBwAHQAYQBuAGMAZQAgAG8AZgAgAHQAaABlACAARABpAGcAaQBDAGUA
# cgB0ACAAQwBQAC8AQwBQAFMAIABhAG4AZAAgAHQAaABlACAAUgBlAGwAeQBpAG4A
# ZwAgAFAAYQByAHQAeQAgAEEAZwByAGUAZQBtAGUAbgB0ACAAdwBoAGkAYwBoACAA
# bABpAG0AaQB0ACAAbABpAGEAYgBpAGwAaQB0AHkAIABhAG4AZAAgAGEAcgBlACAA
# aQBuAGMAbwByAHAAbwByAGEAdABlAGQAIABoAGUAcgBlAGkAbgAgAGIAeQAgAHIA
# ZQBmAGUAcgBlAG4AYwBlAC4wCwYJYIZIAYb9bAMVMBIGA1UdEwEB/wQIMAYBAf8C
# AQAweQYIKwYBBQUHAQEEbTBrMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdp
# Y2VydC5jb20wQwYIKwYBBQUHMAKGN2h0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNv
# bS9EaWdpQ2VydEFzc3VyZWRJRFJvb3RDQS5jcnQwgYEGA1UdHwR6MHgwOqA4oDaG
# NGh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3VyZWRJRFJvb3RD
# QS5jcmwwOqA4oDaGNGh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFz
# c3VyZWRJRFJvb3RDQS5jcmwwHQYDVR0OBBYEFBUAEisTmLKZB+0e36K+Vw0rZwLN
# MB8GA1UdIwQYMBaAFEXroq/0ksuCMS1Ri6enIZ3zbcgPMA0GCSqGSIb3DQEBBQUA
# A4IBAQBGUD7Jtygkpzgdtlspr1LPUukxR6tWXHvVDQtBs+/sdR90OPKyXGGinJXD
# UOSCuSPRujqGcq04eKx1XRcXNHJHhZRW0eu7NoR3zCSl8wQZVann4+erYs37iy2Q
# wsDStZS9Xk+xBdIOPRqpFFumhjFiqKgz5Js5p8T1zh14dpQlc+Qqq8+cdkvtX8JL
# FuRLcEwAiR78xXm8TBJX/l/hHrwCXaj++wc4Tw3GXZG5D2dFzdaD7eeSDY2xaYxP
# +1ngIw/Sqq4AfO6cQg7PkdcntxbuD8O9fAqg7iwIVYUiuOsYGk38KiGtSTGDR5V3
# cdyxG0tLHBCcdxTBnU8vWpUIKRAmMYIEMDCCBCwCAQEwgYMwbzELMAkGA1UEBhMC
# VVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0
# LmNvbTEuMCwGA1UEAxMlRGlnaUNlcnQgQXNzdXJlZCBJRCBDb2RlIFNpZ25pbmcg
# Q0EtMQIQB8qTqm0nsP0uM5ONfO7PYDAJBgUrDgMCGgUAoHAwEAYKKwYBBAGCNwIB
# DDECMAAwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
# MAwGCisGAQQBgjcCARUwIwYJKoZIhvcNAQkEMRYEFJuKBES8KLS7OopVhx3MZ0p3
# us6IMA0GCSqGSIb3DQEBAQUABIIBAGs3N8o9yOzalcLE6hls9XrayqXg/sERkU9F
# 1lFUIAnnE8yOM0h4NQxPj3gRx86oeaVtAaCv7qM0+lvNI6rCuWPBtLuXxywViOhR
# aDgQerrJBEzYGwXKcTR5TUyH+dOQJrM4o3zBuqoOVoZ88hlH8yK2ki8VcbXCz1oK
# 55tep8D0PAFp0XKZ771fzDfg8Aq8CrUpQse4vu7fcwIebwwRWHzq8k9GDLjZegq9
# Un+M0NdyT1pF7dyfc4ebyYSc7Saski5R0AOxnlElIGwgD7zpZ9xqvYldyTQbNJdz
# kvLLkKEMvQVJAHWjldtHiGuLTg1dSS1rApNyk6RoL7x4G8RxCumhggIPMIICCwYJ
# KoZIhvcNAQkGMYIB/DCCAfgCAQEwdjBiMQswCQYDVQQGEwJVUzEVMBMGA1UEChMM
# RGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMSEwHwYDVQQD
# ExhEaWdpQ2VydCBBc3N1cmVkIElEIENBLTECEAOf7e3LeVuN7TIMiRnwNokwCQYF
# Kw4DAhoFAKBdMBgGCSqGSIb3DQEJAzELBgkqhkiG9w0BBwEwHAYJKoZIhvcNAQkF
# MQ8XDTEzMTIxNjE3MDgwMVowIwYJKoZIhvcNAQkEMRYEFMf8muYJlkqWq5JHorRP
# P594sO1PMA0GCSqGSIb3DQEBAQUABIIBAH/lmbYOrDcJL6qjihMvdXL+0UDfjDDP
# 9i27slpWWoXPGCS8FX3IIMCVDAgnyVuFA+hIKub0B8ldaYtRBAPsG6TrLV3OlKuO
# zwEJUOWfAPMpUbhMSywvHAICLK61PIuyFmfDwxWgljLrTMqzKLJUrzNZV7kwp8AT
# MNuzl56+vtjofQjub5rbm5RTONwgfVjgh1J2IBHmb1rb4gYI+aAhdQjXUeXVzi75
# 3gYq4TURUsqRhDeaQsS8FVJN3Ui9uIJJiiDc50DYQpQP0OYAf+bR5ERi/TRaPa+s
# p0ZawvypLrASOF7BEWaxCrgPA/7E2RE+fl+GbtwE+xUWdwQugZeU8rc=
# SIG # End signature block
